# Generated by Django 3.0.6 on 2020-05-28 15:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0043_auto_20200528_1555"),
    ]

    operations = [
        migrations.AlterField(
            model_name="followup",
            name="admitted_hospital",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=25,
                null=True,
                verbose_name="If YES, were they admitted to hospital?",
            ),
        ),
        migrations.AlterField(
            model_name="followup",
            name="attended_clinic_sae",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="If YES, submit a <u>Serious Adverse Event</u> Form",
                max_length=25,
                null=True,
                verbose_name="Does the event constitute a <u>Serious Adverse Event</u>",
            ),
        ),
        migrations.AlterField(
            model_name="followup",
            name="prescribed_medication",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=25,
                null=True,
                verbose_name="Was the participant prescribed any other medication at this clinic or hospital visit?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalfollowup",
            name="admitted_hospital",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=25,
                null=True,
                verbose_name="If YES, were they admitted to hospital?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalfollowup",
            name="attended_clinic_sae",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="If YES, submit a <u>Serious Adverse Event</u> Form",
                max_length=25,
                null=True,
                verbose_name="Does the event constitute a <u>Serious Adverse Event</u>",
            ),
        ),
        migrations.AlterField(
            model_name="historicalfollowup",
            name="prescribed_medication",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=25,
                null=True,
                verbose_name="Was the participant prescribed any other medication at this clinic or hospital visit?",
            ),
        ),
    ]
